import argparse
import request_sign_build
import sys

def parse_args_or_exit(argv=None):
    """
    Parse command line options
    """
    parser = argparse.ArgumentParser(description="Generate CR signing request")
    parser.add_argument("branch",
                        help="Branch to use (typically release/<name>/master)")
    parser.add_argument("build",
                        help="Build number to use")
    parser.add_argument("update_name",
                        help="Name of update (e.g. XS74)")
    parser.add_argument("xs_version",
                        help="XenServer marketing version (e.g. 7.4)")
    parser.add_argument("--ics_version",
                        help="Inspur marketing version (e.g. 5.0.30)")
    parser.add_argument("--ics_update_name",
                        help="Inspur update name (e.g. ICS5030)")
    parser.add_argument("--project", required=True,
                        help="Project description (e.g. xs7-cr.json)")
    parser.add_argument("--dry-run", action="store_true", 
                        help="Print request and exit without submitting")
    parser.add_argument("--ics-only", action="store_true",
                        help="Only produce the Inspur signing request")

    return parser.parse_args(argv)

def main(argv):
    """
    Create a CR signing request
    """
    args = parse_args_or_exit(argv)
    print args

    project = request_sign_build.load_project(args.project)
    # Do the replacements etc
    project['deliverables'] = args.branch
    project['updates'].append("%s.iso" % args.update_name)
    project['sources'].append("%s-binpkgs.iso" % args.update_name)
    project['sources'].append("%s-sources.iso" % args.update_name)

    build_path = project['build_path'].format(branch=args.branch, build=args.build, xs_version=args.xs_version, ics_version=args.ics_version)
    release_path = project['release_path'].format(branch=args.branch, build=args.build, xs_version=args.xs_version, ics_version=args.ics_version)

    inspur_project = None
    if args.ics_version:
        inspur_project = project.get("inspur_project")
        if not inspur_project:
            raise Exception("ics_version specified but no inspur_project in project file")
        if not args.ics_update_name:
            raise Exception("ics_update_name not specified")

    # Construct the args for request-sign-build
    rsb_args = [build_path, release_path,
                "--project", args.project]
    rsb_args = request_sign_build.parse_args_or_exit(rsb_args)
    rsb_args.dry_run = args.dry_run
    repo_dir = request_sign_build.checkout_repo(rsb_args.repo)
    if not args.ics_only:
        request_sign_build.add_request(rsb_args, repo_dir, project)

    if inspur_project:
        project = request_sign_build.load_project(inspur_project)
        # Do the replacements etc
        project['deliverables'] = args.branch
        project['updates'].append("%s.iso" % args.ics_update_name)
        project['sources'].append("%s-binpkgs.iso" % args.ics_update_name)
        project['sources'].append("%s-sources.iso" % args.ics_update_name)
        project['sources'].append("%s-full-sources.iso" % args.ics_update_name)

        build_path = project['build_path'].format(branch=args.branch, build=args.build, xs_version=args.xs_version, ics_version=args.ics_version)
        release_path = project['release_path'].format(branch=args.branch, build=args.build, xs_version=args.xs_version, ics_version=args.ics_version)

        rsb_args = [build_path, release_path,
                    "--project", inspur_project]
        rsb_args = request_sign_build.parse_args_or_exit(rsb_args)
        rsb_args.dry_run = args.dry_run
        request_sign_build.add_request(rsb_args, repo_dir, project)

    if not args.dry_run:
        request_sign_build.push_request(repo_dir)

def _main():
    """
    Entry point for setuptools CLI wrapper
    """
    main(sys.argv[1:])


# Entry point when run directly
if __name__ == "__main__":
    _main()

